@@ -31,12 +31,11 @@
 
 #include "xwayland-types.h"
 
-struct xwl_window_buffer;
-
 void xwl_window_buffer_add_damage_region(struct xwl_window *xwl_window);
+void xwl_window_buffer_release(struct xwl_window_buffer *xwl_window_buffer);
 void xwl_window_buffers_init(struct xwl_window *xwl_window);
-void xwl_window_buffers_dispose(struct xwl_window *xwl_window);
+void xwl_window_buffers_dispose(struct xwl_window *xwl_window, Bool force);
 void xwl_window_realloc_pixmap(struct xwl_window *xwl_window);
-PixmapPtr xwl_window_swap_pixmap(struct xwl_window *xwl_window);
+PixmapPtr xwl_window_swap_pixmap(struct xwl_window *xwl_window, Bool handle_sync);
 
 #endif /* XWAYLAND_WINDOW_BUFFERS_H */
